(*====================================================================
  =  Program Id:     WHATQ.MOD                                       =
  =  Programmer:     Peter M. Perchansky                             =
  =  Copyright:      Copyright (c) Peter M. Perchansky 1990          =
  =  Purpose:        Report what printer queue you are currently     =
  =                  using.                                          =
  =  Date Written:   06-28-1990                                      =
  =  Compiler:       TopSpeed Modula-2 2.00.                         =
  =  Memory Model:   Small                                           =
  =------------------------------------------------------------------=
  =                       Version History                            =
  =------------------------------------------------------------------=
  =  07-10-90   PMP Check for empty queues; make sure Novell Loaded. =
  =  06-29-90   PMP Renamed to WHATQ from WHATQUEUE.                 =
  =  06-28-90   PMP Date written.                                    =
  ====================================================================*)

(*#check (stack=>off, index=>off, range=>off, overflow=>off, nil_ptr=>off) *)
(*#optimize (speed=>on, cse=>on, const=>on, peep_hole=>on, jump=>on,
             loop=>on, alias=>on, regass=>on, stk_frame=>on, i186=>on) *)

MODULE WhatQ;

(*------------- Procedures from JPI's TopSpeed Modula II -------------*)
FROM IO     IMPORT WrLn, WrStr;
(*--------------------------------------------------------------------*)

(*------------- Procedures from PMP's Library Modules ----------------*)
FROM PMPNet IMPORT MAXCARD, PrinterPorts, PrinterQueue, GetPrinterQueue;
FROM PMPNet IMPORT NetworkLoaded;
FROM PMPStr IMPORT AssignStr, EmptyStr, LocateEnd, RightStr, SPos;
(*--------------------------------------------------------------------*)

CONST
    COPYRIGHT = "     Copyright (c) Peter M. Perchansky 1990";
    TITLE     = "WhatQ - What printer queue are you using?";
    VERSION   = "v1.03";

PROCEDURE WriteOpening ();
(* Display opening screen.                                            *)

BEGIN
    WrLn; WrStr (TITLE); WrStr (" - "); WrStr (VERSION);
    WrLn; WrStr (COPYRIGHT); WrLn;

END WriteOpening;

PROCEDURE WriteError (message: ARRAY OF CHAR);
(* Display error message.                                             *)

BEGIN
    WrLn;
    WrStr ("ERROR:  ");
    WrStr (message);
    WrLn;
END WriteError;

PROCEDURE Parse (item: ARRAY OF CHAR; VAR into: ARRAY OF CHAR);
(* Remove "FS1\\SYS\" from item; remainder transfered to into.        *)

VAR
    len,
    pos : CARDINAL;

BEGIN
    len := LocateEnd (item);
    pos := SPos (item, "\\", 0);                (* find "FS1\\" *)
    IF pos # MAXCARD THEN
       pos := SPos (item, "\", pos + 2);        (* find "SYS\"  *)
       IF pos # MAXCARD THEN
          RightStr (item, into, len - pos - 1)
       ELSE
          AssignStr (item, into)
       END;
    ELSE
       pos := SPos (item, "\", 0);              (* find "SYS\"  *)
       IF pos # MAXCARD THEN
          RightStr (item, into, len - pos - 1)
       ELSE
          AssignStr (item, into)
       END;
    END;
END Parse;

VAR
    q,                            (* actual printer queue *)
    queue : PrinterQueue;         (* work buffer          *)

BEGIN
    WriteOpening ();
    IF NetworkLoaded () THEN
       IF GetPrinterQueue (lpt1, queue) THEN
          Parse (queue, q);
          IF NOT EmptyStr (q) THEN
             WrLn;
             WrStr ("You are setup to capture on the ");
             WrStr (q); WrStr (" printer queue.");
             WrLn;
          ELSE
             WriteError ("You are not setup to capture to a printer queue.")
          END;
       ELSE
          WriteError ("You are not setup to capture to a printer queue.")
       END;
    ELSE
       WriteError ("You do not have access to a network.")
    END;
END WhatQ.
